@@ -3,7 +3,7 @@
 
 pub mod association;
 pub mod chunk;
-pub mod error;
+mod error;
 pub mod error_cause;
 pub mod packet;
 pub mod param;
@@ -11,3 +11,5 @@ pub(crate) mod queue;
 pub mod stream;
 pub(crate) mod timer;
 pub(crate) mod util;
+
+pub use error::Error;
