@@ -1,17 +1,22 @@
-use anyhow::Result;
 use async_trait::async_trait;
 use std::sync::atomic::{AtomicU32, Ordering};
 use std::sync::Arc;
 use std::time::SystemTime;
-use tokio::sync::{mpsc, Mutex};
+
+use tokio::sync::mpsc;
+use tokio::sync::Mutex;
 use tokio::time::{sleep, Duration};
 
+use crate::error::Result;
+
 ///////////////////////////////////////////////////////////////////
 //ack_timer_test
 ///////////////////////////////////////////////////////////////////
 use super::ack_timer::*;
 
 mod test_ack_timer {
+    use crate::error::Result;
+
     use super::*;
 
     struct TestAckTimerObserver {
@@ -71,6 +76,8 @@ mod test_ack_timer {
 use super::rtx_timer::*;
 
 mod test_rto_manager {
+    use crate::error::Result;
+
     use super::*;
 
     #[tokio::test]
